/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdint.h>


/* --------- TPS274C65_FAULT_TYPE_STAT (0x00) ----------*/
/* DESCRIPTION: The register reports the fault type in any of the channels 
 *             (OR of all channels) */

#define TPS274C65_FAULT_TYPE_STAT_REG 0x00

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if there is a global fault reported in the FLT_GLOBAL_TYPE 
        * register (SPI error, watchdog error, VS_UV_WRN fault or chip thermal warning 
        * occurs. If FLT_LTCH_DIS bit is set, then the fault bit is latched and is 
        * cleared only when the FLT_GLOBAL_TYPE register is read and the fault condition 
        * no longer exists. */
        unsigned GLOBAL_ERR_WRN : 1;
        /* The bit is set if there is a short to VS supply in the off-state fault 
        * in any one of the channels. If FLT_LTCH_DIS bit is set, then the fault 
        * bit is latched and is cleared only when the SHRT_VS_CH_STAT register is 
        * read and the fault condition no longer exists */
        unsigned SHRT_VS_FLT : 1;
        /* The bit is set if either there is a wire break in the off-state fault 
        * in any one of the channels. If FLT_LTCH_DIS bit is set, then the fault 
        * bit is latched and is cleared only when the WB_OFF_CH_STAT register is 
        * read and the fault condition no longer exists */
        unsigned WB_OFF_FLT : 1;
        /* The bit is set if there is a wire break in the on state fault in any one 
        * of the channels. If FLT_LTCH_DIS bit is set, then the fault bit is latched 
        * and is cleared only when the WB_ON_CH_STAT register is read and the fault 
        * condition no longer exists */
        unsigned WB_ON_FLT : 1;
        /* The bit is set if there is a current limit fault due to ovecurrent in 
        * any one of the channels. If FLT_LTCH_DIS bit is set, then the fault bit 
        * is latched and is cleared only when the ILIMIT_CH_STAT register is read 
        * and the fault condition no longer exists. */
        unsigned ILIMIT_FLT : 1;
        /* The bit is set if there is a thermal shutdown fault due to thermal overload 
        * in any one of the channels. If FLT_LTCH_DIS bit is set, then the fault 
        * bit is latched and is cleared only when the THERMAL_SD_CH_STAT register 
        * is read and the fault condition no longer exists. */
        unsigned CHAN_TSD : 1;
        /* The bit is set if there is a reverse current fault in any one of the channels. 
        * If FLT_LTCH_DIS bit is set, then the fault bit is latched and is cleared 
        * only when the RVRS_BLK_CH_STAT register is read and the fault condition 
        * no longer exists. */
        unsigned RVRS_BLK_FLT : 1;
        /* The bit is set if either the VDD_UVLO or VS_UV are faults occur. If FLT_LTCH_DIS 
        * bit is set, then the fault bit is latched and is cleared only when the 
        * FLT_GLOBAL_TYPE register is read and the fault condition no longer exists. 
        * */
        unsigned SUPPLY_FLT : 1;
    } bits;
} TPS274C65_FAULT_TYPE_STAT;

#define TPS274C65_FAULT_TYPE_STAT_GLOBAL_ERR_WRN_MASK 0x01

typedef enum {
    global_err_wrn_en1 = 0x0,
    global_err_wrn_en2 = 0x1,
} global_err_wrn_t;

#define TPS274C65_FAULT_TYPE_STAT_SHRT_VS_FLT_MASK 0x02

typedef enum {
    shrt_vs_flt_en_1_0x0 = 0x0,
    shrt_vs_flt_en_2_0x1 = 0x2,
} shrt_vs_flt_t;

#define TPS274C65_FAULT_TYPE_STAT_WB_OFF_FLT_MASK 0x04

typedef enum {
    wb_off_flt_en_1_0x0 = 0x0,
    wb_off_flt_en_2_0x1 = 0x4,
} wb_off_flt_t;

#define TPS274C65_FAULT_TYPE_STAT_WB_ON_FLT_MASK 0x08

typedef enum {
    wb_on_flt_en_1_0x0 = 0x0,
    wb_on_flt_en_2_0x1 = 0x8,
} wb_on_flt_t;

#define TPS274C65_FAULT_TYPE_STAT_ILIMIT_FLT_MASK 0x10

typedef enum {
    ilimit_flt_en_1_0x0 = 0x0,
    ilimit_flt_en_2_0x1 = 0x10,
} ilimit_flt_t;

#define TPS274C65_FAULT_TYPE_STAT_CHAN_TSD_MASK 0x20

typedef enum {
    chan_tsd_en_1_0x0 = 0x0,
    chan_tsd_en_2_0x1 = 0x20,
} chan_tsd_t;

#define TPS274C65_FAULT_TYPE_STAT_RVRS_BLK_FLT_MASK 0x40

typedef enum {
    rvrs_blk_flt_en_1_0x0 = 0x0,
    rvrs_blk_flt_en_2_0x1 = 0x40,
} rvrs_blk_flt_t;

#define TPS274C65_FAULT_TYPE_STAT_SUPPLY_FLT_MASK 0x80

typedef enum {
    supply_flt_en_1_0x0 = 0x0,
    supply_flt_en_2_0x1 = 0x80,
} supply_flt_t;


/* --------- TPS274C65_FAULT_CH_STAT (0x01) ----------*/
/* DESCRIPTION: The register reports faulted channel(s) (OR of all fault 
 *             types in each channel) */

#define TPS274C65_FAULT_CH_STAT_REG 0x01

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if any type of fault (RVRS_BLK, THERMAL_SD_CH, ILIMIT, 
        * WB_ON, WB_OFF, SHRT_VS) occurs in CH1 */
        unsigned CH1 : 1;
        /* The bit is set if any type of fault (RVRS_BLK, THERMAL_SD_CH, ILIMIT, 
        * WB_ON, WB_OFF, SHRT_VS) occurs in CH2 */
        unsigned CH2 : 1;
        /* The bit is set if any type of fault (RVRS_BLK, THERMAL_SD_CH, ILIMIT, 
        * WB_ON, WB_OFF, SHRT_VS) occurs in CH3 */
        unsigned CH3 : 1;
        /* The bit is set if any type of fault (RVRS_BLK, THERMAL_SD_CH, ILIMIT, 
        * WB_ON, WB_OFF, SHRT_VS) occurs in CH4 */
        unsigned CH4 : 1;
        /* Reserved */
        unsigned RESERVED_1 : 4;
    } bits;
} TPS274C65_FAULT_CH_STAT;

#define TPS274C65_FAULT_CH_STAT_CH1_MASK 0x01

typedef enum {
    ch1_en_1_0x0 = 0x0,
    ch1_en_2_0x1 = 0x1,
} ch1_t;

#define TPS274C65_FAULT_CH_STAT_CH2_MASK 0x02

typedef enum {
    ch2_en_1_0x0 = 0x0,
    ch2_en_2_0x1 = 0x2,
} ch2_t;

#define TPS274C65_FAULT_CH_STAT_CH3_MASK 0x04

typedef enum {
    ch3_en_1_0x0 = 0x0,
    ch3_en_2_0x1 = 0x4,
} ch3_t;

#define TPS274C65_FAULT_CH_STAT_CH4_MASK 0x08

typedef enum {
    ch4_en_1_0x0 = 0x0,
    ch4_en_2_0x1 = 0x8,
} ch4_t;

#define TPS274C65_FAULT_CH_STAT_RESERVED_1_MASK 0xF0

/* --------- TPS274C65_FAULT_GLOBAL_TYPE (0x02) ----------*/
/* DESCRIPTION: The register reports the type of global fault that has occurred 
 *             in the IC */

#define TPS274C65_FAULT_GLOBAL_TYPE_REG 0x02

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if VS supply is below the UV threshold at any time. The 
        * fault bit is cleared if the GLOBAL_FAULT_TYPE register is read and the 
        * UV condition is removed */
        unsigned VS_UV : 1;
        /* The bit is set if VS supply is below the UV warning (UV_WRN) threshold 
        * at any time. The fault bit is cleared if the GLOBAL_FAULT_TYPE register 
        * is read and the UV condition is removed */
        unsigned VS_UV_WRN : 1;
        /* The bit is set if VDD supply is below the UVLO threshold at any time. 
        * The fault bit is cleared if the GLOBAL_FAULT_TYPE register is read and 
        * the UVLO condition is removed */
        unsigned VDD_UVLO : 1;
        /* The bit is set if the watchdog timeout on SPI read or write occurs. The 
        * fault bit is latched and cleared only after read and the error is removed. 
        * */
        unsigned WD_ERR : 1;
        /* The bit is set if there is an SPI communication error either from format, 
        * clock or CRC errors.The fault bit is latched and cleared only after read 
        * and the error is removed. */
        unsigned SPI_ERR : 1;
        /* The bit is set if the chip thermal warning is triggered at any time. The 
        * fault bit is cleared if the GLOBAL_FAULT_TYPE register is read and the 
        * chip thermal shutdown error condition is removed */
        unsigned CHIP_THERMALSD : 1;
        /* The bit is indicative of whether a power on reset has occurred. */
        unsigned POR : 1;
        /* Reserved */
        unsigned RESERVED_2 : 1;
    } bits;
} TPS274C65_FAULT_GLOBAL_TYPE;

#define TPS274C65_FAULT_GLOBAL_TYPE_VS_UV_MASK 0x01

typedef enum {
    vs_uv_en_1_0x0 = 0x0,
    vs_uv_en_2_0x1 = 0x1,
} vs_uv_t;

#define TPS274C65_FAULT_GLOBAL_TYPE_VS_UV_WRN_MASK 0x02

typedef enum {
    vs_uv_wrn_en_1_0x0 = 0x0,
    vs_uv_wrn_en_2_0x1 = 0x2,
} vs_uv_wrn_t;

#define TPS274C65_FAULT_GLOBAL_TYPE_VDD_UVLO_MASK 0x04

typedef enum {
    vdd_uvlo_en_1_0x0 = 0x0,
    vdd_uvlo_en_2_0x1 = 0x4,
} vdd_uvlo_t;

#define TPS274C65_FAULT_GLOBAL_TYPE_WD_ERR_MASK 0x08

typedef enum {
    wd_err_en_1_0x0 = 0x0,
    wd_err_en_2_0x1 = 0x8,
} wd_err_t;

#define TPS274C65_FAULT_GLOBAL_TYPE_SPI_ERR_MASK 0x10

typedef enum {
    spi_err_en_1_0x0 = 0x0,
    spi_err_en_2_0x1 = 0x10,
} spi_err_t;

#define TPS274C65_FAULT_GLOBAL_TYPE_CHIP_THERMALSD_MASK 0x20

typedef enum {
    chip_thermalsd_en_1_0x0 = 0x0,
    chip_thermalsd_en_2_0x1 = 0x20,
} chip_thermalsd_t;

#define TPS274C65_FAULT_GLOBAL_TYPE_POR_MASK 0x40

typedef enum {
    por_en_1_0x0 = 0x0,
    por_en_2_0x1 = 0x40,
} por_t;

#define TPS274C65_FAULT_GLOBAL_TYPE_RESERVED_2_MASK 0x80

/* --------- TPS274C65_SHRT_VS_CH_STAT (0x03) ----------*/
/* DESCRIPTION: The register reports faulted channel(s) with the off-state 
 *             short-to-supply fault */

#define TPS274C65_SHRT_VS_CH_STAT_REG 0x03

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if any short to supply (VS) fault has occurred at any time 
        * in CH1. The fault is latched and cleared when the SHRT_VS_CH_STAT register 
        * is read and fault condition does not exist anymore. */
        unsigned SHRT_VS_CH1 : 1;
        /* The bit is set if any short to supply (VS) fault has occurred at any time 
        * in CH2. The fault is latched and cleared when the SHRT_VS_CH_STAT register 
        * is read and fault condition does not exist anymore. */
        unsigned SHRT_VS_CH2 : 1;
        /* The bit is set if any short to supply (VS) fault has occurred at any time 
        * in CH3. The fault is latched and cleared when the SHRT_VS_CH_STAT register 
        * is read and fault condition does not exist anymore. */
        unsigned SHRT_VS_CH3 : 1;
        /* The bit is set if any short to supply (VS) fault has occurred at any time 
        * in CH4. The fault is latched and cleared when the SHRT_VS_CH_STAT register 
        * is read and fault condition does not exist anymore. */
        unsigned SHRT_VS_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_4 : 4;
    } bits;
} TPS274C65_SHRT_VS_CH_STAT;

#define TPS274C65_SHRT_VS_CH_STAT_SHRT_VS_CH1_MASK 0x01

typedef enum {
    shrt_vs_ch1_en_1_0x0 = 0x0,
    shrt_vs_ch1_en_2_0x1 = 0x1,
} shrt_vs_ch1_t;

#define TPS274C65_SHRT_VS_CH_STAT_SHRT_VS_CH2_MASK 0x02

typedef enum {
    shrt_vs_ch2_en_1_0x0 = 0x0,
    shrt_vs_ch2_en_2_0x1 = 0x2,
} shrt_vs_ch2_t;

#define TPS274C65_SHRT_VS_CH_STAT_SHRT_VS_CH3_MASK 0x04

typedef enum {
    shrt_vs_ch3_en_1_0x0 = 0x0,
    shrt_vs_ch3_en_2_0x1 = 0x4,
} shrt_vs_ch3_t;

#define TPS274C65_SHRT_VS_CH_STAT_SHRT_VS_CH4_MASK 0x08

typedef enum {
    shrt_vs_ch4_en_1_0x0 = 0x0,
    shrt_vs_ch4_en_2_0x1 = 0x8,
} shrt_vs_ch4_t;

#define TPS274C65_SHRT_VS_CH_STAT_RESERVED_4_MASK 0xF0

/* --------- TPS274C65_WB_OFF_CH_STAT (0x04) ----------*/
/* DESCRIPTION: The register reports faulted channel(s) with the off-state 
 *             wire-break fault */

#define TPS274C65_WB_OFF_CH_STAT_REG 0x04

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if the wire break (open load) fault in off-state has occurred 
        * at any time in CH1. The fault is latched and cleared when the WB_OFF_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned WB_OFF_CH1 : 1;
        /* The bit is set if the wire break (open load) fault in off-state has occurred 
        * at any time in CH2. The fault is latched and cleared when the WB_OFF_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned WB_OFF_CH2 : 1;
        /* The bit is set if the wire break (open load) fault in off-state has occurred 
        * at any time in CH3. The fault is latched and cleared when the WB_OFF_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned WB_OFF_CH3 : 1;
        /* The bit is set if the wire break (open load) fault in off-state has occurred 
        * at any time in CH4. The fault is latched and cleared when the WB_OFF_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned WB_OFF_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_6 : 4;
    } bits;
} TPS274C65_WB_OFF_CH_STAT;

#define TPS274C65_WB_OFF_CH_STAT_WB_OFF_CH1_MASK 0x01

typedef enum {
    wb_off_ch1_en_1_0x0 = 0x0,
    wb_off_ch1_en_2_0x1 = 0x1,
} wb_off_ch1_t;

#define TPS274C65_WB_OFF_CH_STAT_WB_OFF_CH2_MASK 0x02

typedef enum {
    wb_off_ch2_en_1_0x0 = 0x0,
    wb_off_ch2_en_2_0x1 = 0x2,
} wb_off_ch2_t;

#define TPS274C65_WB_OFF_CH_STAT_WB_OFF_CH3_MASK 0x04

typedef enum {
    wb_off_ch3_en_1_0x0 = 0x0,
    wb_off_ch3_en_2_0x1 = 0x4,
} wb_off_ch3_t;

#define TPS274C65_WB_OFF_CH_STAT_WB_OFF_CH4_MASK 0x08

typedef enum {
    wb_off_ch4_en_1_0x0 = 0x0,
    wb_off_ch4_en_2_0x1 = 0x8,
} wb_off_ch4_t;

#define TPS274C65_WB_OFF_CH_STAT_RESERVED_6_MASK 0xF0

/* --------- TPS274C65_WB_ON_CH_STAT (0x05) ----------*/
/* DESCRIPTION: The register reports faulted channel(s) with the on-state 
 *             wire-break fault */

#define TPS274C65_WB_ON_CH_STAT_REG 0x05

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if the wire break (open load) fault in off-state has occurred 
        * at any time in CH1. The fault is latched and cleared when the WB_OFF_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned WB_ON_CH1 : 1;
        /* The bit is set if the wire break (open load) fault in off-state has occurred 
        * at any time in CH2. The fault is latched and cleared when the WB_OFF_CH_STAT 
        * register is read and fault condition is cleared. */
        unsigned WB_ON_CH2 : 1;
        /* The bit is set if the wire break (open load) fault in off-state has occurred 
        * at any time in CH3. The fault is latched and cleared when the WB_OFF_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned WB_ON_CH3 : 1;
        /* The bit is set if the wire break (open load) fault in off-state has occurred 
        * at any time in CH4. The fault is latched and cleared when the WB_OFF_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned WB_ON_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_8 : 4;
    } bits;
} TPS274C65_WB_ON_CH_STAT;

#define TPS274C65_WB_ON_CH_STAT_WB_ON_CH1_MASK 0x01

typedef enum {
    wb_on_ch1_en_1_0x0 = 0x0,
    wb_on_ch1_en_2_0x1 = 0x1,
} wb_on_ch1_t;

#define TPS274C65_WB_ON_CH_STAT_WB_ON_CH2_MASK 0x02

typedef enum {
    wb_on_ch2_en_1_0x0 = 0x0,
    wb_on_ch2_en_2_0x1 = 0x2,
} wb_on_ch2_t;

#define TPS274C65_WB_ON_CH_STAT_WB_ON_CH3_MASK 0x04

typedef enum {
    wb_on_ch3_en_1_0x0 = 0x0,
    wb_on_ch3_en_2_0x1 = 0x4,
} wb_on_ch3_t;

#define TPS274C65_WB_ON_CH_STAT_WB_ON_CH4_MASK 0x08

typedef enum {
    wb_on_ch4_en_1_0x0 = 0x0,
    wb_on_ch4_en_2_0x1 = 0x8,
} wb_on_ch4_t;

#define TPS274C65_WB_ON_CH_STAT_RESERVED_8_MASK 0xF0

/* --------- TPS274C65_ILIMIT_CH_STAT (0x06) ----------*/
/* DESCRIPTION: The register reports faulted channel(s) with the current 
 *             limit fault */

#define TPS274C65_ILIMIT_CH_STAT_REG 0x06

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if current limiting due to overcurrent has occurred at 
        * any time in CH1. The fault is latched and cleared when the ILIMIT_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned ILIMIT_CH1 : 1;
        /* The bit is set if current limiting due to overcurrent has occurred at 
        * any time in CH2. The fault is latched and cleared when the ILIMIT_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned ILIMIT_CH2 : 1;
        /* The bit is set if current limiting due to overcurrent has occurred at 
        * any time in CH3. The fault is latched and cleared when the ILIMIT_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned ILIMIT_CH3 : 1;
        /* The bit is set if current limiting due to overcurrent has occurred at 
        * any time in CH4. The fault is latched and cleared when the ILIMIT_CH_STAT 
        * register is read and fault condition does not exist anymore. */
        unsigned ILIMIT_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_10 : 4;
    } bits;
} TPS274C65_ILIMIT_CH_STAT;

#define TPS274C65_ILIMIT_CH_STAT_ILIMIT_CH1_MASK 0x01

typedef enum {
    ilimit_ch1_en_1_0x0 = 0x0,
    ilimit_ch1_en_2_0x1 = 0x1,
} ilimit_ch1_t;

#define TPS274C65_ILIMIT_CH_STAT_ILIMIT_CH2_MASK 0x02

typedef enum {
    ilimit_ch2_en_1_0x0 = 0x0,
    ilimit_ch2_en_2_0x1 = 0x2,
} ilimit_ch2_t;

#define TPS274C65_ILIMIT_CH_STAT_ILIMIT_CH3_MASK 0x04

typedef enum {
    ilimit_ch3_en_1_0x0 = 0x0,
    ilimit_ch3_en_2_0x1 = 0x4,
} ilimit_ch3_t;

#define TPS274C65_ILIMIT_CH_STAT_ILIMIT_CH4_MASK 0x08

typedef enum {
    ilimit_ch4_en_1_0x0 = 0x0,
    ilimit_ch4_en_2_0x1 = 0x8,
} ilimit_ch4_t;

#define TPS274C65_ILIMIT_CH_STAT_RESERVED_10_MASK 0xF0

/* --------- TPS274C65_THERMAL_SD_CH_STAT (0x07) ----------*/
/* DESCRIPTION: The register reports faulted channel(s) with the thermal 
 *             shutdown fault */

#define TPS274C65_THERMAL_SD_CH_STAT_REG 0x07

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if the thermal shutdown has occurred at any time in CH1. 
        * The fault is latched and cleared when the THERMAL_SD_CH_STAT register is 
        * read and channel temperature has fallen below the thermal shutdown reset 
        * threshold. */
        unsigned THERMAL_SD_CH1 : 1;
        /* The bit is set if the thermal shutdown has occurred at any time in CH2. 
        * The fault is latched and cleared when the THERMAL_SD_CH_STAT register is 
        * read and channel temperature has fallen below the thermal shutdown reset 
        * threshold. */
        unsigned THERMAL_SD_CH2 : 1;
        /* The bit is set if the thermal shutdown has occurred at any time in CH3. 
        * The fault is latched and cleared when the THERMAL_SD_CH_STAT register is 
        * read and channel temperature has fallen below the thermal shutdown reset 
        * threshold. */
        unsigned THERMAL_SD_CH3 : 1;
        /* The bit is set if the thermal shutdown has occurred at any time in CH4. 
        * The fault is latched and cleared when the THERMAL_SD_CH_STAT register is 
        * read and channel temperature has fallen below the thermal shutdown reset 
        * threshold. */
        unsigned THERMAL_SD_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_12 : 4;
    } bits;
} TPS274C65_THERMAL_SD_CH_STAT;

#define TPS274C65_THERMAL_SD_CH_STAT_THERMAL_SD_CH1_MASK 0x01

typedef enum {
    thermal_sd_ch1_en_1_0x0 = 0x0,
    thermal_sd_ch1_en_2_0x1 = 0x1,
} thermal_sd_ch1_t;

#define TPS274C65_THERMAL_SD_CH_STAT_THERMAL_SD_CH2_MASK 0x02

typedef enum {
    thermal_sd_ch2_en_1_0x0 = 0x0,
    thermal_sd_ch2_en_2_0x1 = 0x2,
} thermal_sd_ch2_t;

#define TPS274C65_THERMAL_SD_CH_STAT_THERMAL_SD_CH3_MASK 0x04

typedef enum {
    thermal_sd_ch3_en_1_0x0 = 0x0,
    thermal_sd_ch3_en_2_0x1 = 0x4,
} thermal_sd_ch3_t;

#define TPS274C65_THERMAL_SD_CH_STAT_THERMAL_SD_CH4_MASK 0x08

typedef enum {
    thermal_sd_ch4_en_1_0x0 = 0x0,
    thermal_sd_ch4_en_2_0x1 = 0x8,
} thermal_sd_ch4_t;

#define TPS274C65_THERMAL_SD_CH_STAT_RESERVED_12_MASK 0xF0

/* --------- TPS274C65_THERMAL_WRN_CH_STAT (0x08) ----------*/
/* DESCRIPTION: The register reports channel(s) with the temperature above 
 *             thermal warning threshold */

#define TPS274C65_THERMAL_WRN_CH_STAT_REG 0x08

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if FET temperature is above the overtemperature warning 
        * threshold in CH1. The bit is cleared when over-temperature earning condition 
        * does not exist anymore. */
        unsigned THERMAL_WRN_CH1 : 1;
        /* The bit is set if FET temperature is above the overtemperature warning 
        * threshold in CH2. The bit is cleared when over-temperature earning condition 
        * does not exist anymore. */
        unsigned THERMAL_WRN_CH2 : 1;
        /* The bit is set if FET temperature is above the overtemperature warning 
        * threshold in CH3. The bit is cleared when over-temperature earning condition 
        * does not exist anymore. */
        unsigned THERMAL_WRN_CH3 : 1;
        /* The bit is set if FET temperature is above the overtemperature warning 
        * threshold in CH4. The bit is cleared when over-temperature earning condition 
        * does not exist anymore. */
        unsigned THERMAL_WRN_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_14 : 4;
    } bits;
} TPS274C65_THERMAL_WRN_CH_STAT;

#define TPS274C65_THERMAL_WRN_CH_STAT_THERMAL_WRN_CH1_MASK 0x01

typedef enum {
    thermal_wrn_ch1_en_1_0x0 = 0x0,
    thermal_wrn_ch1_en_2_0x1 = 0x1,
} thermal_wrn_ch1_t;

#define TPS274C65_THERMAL_WRN_CH_STAT_THERMAL_WRN_CH2_MASK 0x02

typedef enum {
    thermal_wrn_ch2_en_1_0x0 = 0x0,
    thermal_wrn_ch2_en_2_0x1 = 0x2,
} thermal_wrn_ch2_t;

#define TPS274C65_THERMAL_WRN_CH_STAT_THERMAL_WRN_CH3_MASK 0x04

typedef enum {
    thermal_wrn_ch3_en_1_0x0 = 0x0,
    thermal_wrn_ch3_en_2_0x1 = 0x4,
} thermal_wrn_ch3_t;

#define TPS274C65_THERMAL_WRN_CH_STAT_THERMAL_WRN_CH4_MASK 0x08

typedef enum {
    thermal_wrn_ch4_en_1_0x0 = 0x0,
    thermal_wrn_ch4_en_2_0x1 = 0x8,
} thermal_wrn_ch4_t;

#define TPS274C65_THERMAL_WRN_CH_STAT_RESERVED_14_MASK 0xF0

/* --------- TPS274C65_RVRS_BLK_CH_STAT (0x09) ----------*/
/* DESCRIPTION: The register reports faulted channel(s) with the reverse 
 *             current flow (blocked) fault */

#define TPS274C65_RVRS_BLK_CH_STAT_REG 0x09

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set if the reverse current fault (blocked) has occurred at 
        * any time in CH1. The fault is latched and cleared when the RVRS_BLK_CH_STAT 
        * register is read. */
        unsigned RVRS_BLK_CH1 : 1;
        /* The bit is set if the reverse current fault (blocked) has occurred at 
        * any time in CH2. The fault is latched and cleared when the RVRS_BLK_CH_STAT 
        * register is read. */
        unsigned RVRS_BLK_CH2 : 1;
        /* The bit is set if the reverse current fault (blocked) has occurred at 
        * any time in CH3. The fault is latched and cleared when the RVRS_BLK_CH_STAT 
        * register is read. */
        unsigned RVRS_BLK_CH3 : 1;
        /* The bit is set if the reverse current fault (blocked) has occurred at 
        * any time in CH4. The fault is latched and cleared when the RVRS_BLK_CH_STAT 
        * register is read. */
        unsigned RVRS_BLK_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_16 : 4;
    } bits;
} TPS274C65_RVRS_BLK_CH_STAT;

#define TPS274C65_RVRS_BLK_CH_STAT_RVRS_BLK_CH1_MASK 0x01

typedef enum {
    rvrs_blk_ch1_en_1_0x0 = 0x0,
    rvrs_blk_ch1_en_2_0x1 = 0x1,
} rvrs_blk_ch1_t;

#define TPS274C65_RVRS_BLK_CH_STAT_RVRS_BLK_CH2_MASK 0x02

typedef enum {
    rvrs_blk_ch2_en_1_0x0 = 0x0,
    rvrs_blk_ch2_en_2_0x1 = 0x2,
} rvrs_blk_ch2_t;

#define TPS274C65_RVRS_BLK_CH_STAT_RVRS_BLK_CH3_MASK 0x04

typedef enum {
    rvrs_blk_ch3_en_1_0x0 = 0x0,
    rvrs_blk_ch3_en_2_0x1 = 0x4,
} rvrs_blk_ch3_t;

#define TPS274C65_RVRS_BLK_CH_STAT_RVRS_BLK_CH4_MASK 0x08

typedef enum {
    rvrs_blk_ch4_en_1_0x0 = 0x0,
    rvrs_blk_ch4_en_2_0x1 = 0x8,
} rvrs_blk_ch4_t;

#define TPS274C65_RVRS_BLK_CH_STAT_RESERVED_16_MASK 0xF0

/* --------- TPS274C65_RESERVED_1 (0x0A) ----------*/
/* DESCRIPTION: The register reports faulted channel(s) with the reverse 
 *             current flow (blocked) fault */

#define TPS274C65_RESERVED_1_REG 0x0A

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Reserved */
        unsigned RESERVED_18 : 8;
    } bits;
} TPS274C65_RESERVED_1;

#define TPS274C65_RESERVED_1_RESERVED_18_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH1_I (0x0B) ----------*/
/* DESCRIPTION: The register records ADC conversion result for current sense 
 *             of CH1 */

#define TPS274C65_ADC_RESULT_CH1_I_REG 0x0B

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the current in CH1 */
        unsigned ADC_ISNS_CH1 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH1_I;

#define TPS274C65_ADC_RESULT_CH1_I_ADC_ISNS_CH1_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH1_I_LSB (0x0C) ----------*/
/* DESCRIPTION: The register records ADC conversion result for current sense 
 *             of CH1 (Two LSBs) */

#define TPS274C65_ADC_RESULT_CH1_I_LSB_REG 0x0C

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Least Significant Bits for ADC result from conversion of the current in 
        * CH1 */
        unsigned ADC_ISNS_CH1_LSB : 2;
        /* Reserved */
        unsigned RESERVED_20 : 6;
    } bits;
} TPS274C65_ADC_RESULT_CH1_I_LSB;

#define TPS274C65_ADC_RESULT_CH1_I_LSB_ADC_ISNS_CH1_LSB_MASK 0x03
#define TPS274C65_ADC_RESULT_CH1_I_LSB_RESERVED_20_MASK 0xFC

/* --------- TPS274C65_ADC_RESULT_CH2_I (0x0D) ----------*/
/* DESCRIPTION: The register records ADC conversion result for current sense 
 *             of CH2 */

#define TPS274C65_ADC_RESULT_CH2_I_REG 0x0D

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the current in CH2 */
        unsigned ADC_ISNS_CH2 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH2_I;

#define TPS274C65_ADC_RESULT_CH2_I_ADC_ISNS_CH2_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH2_I_LSB (0x0E) ----------*/
/* DESCRIPTION: The register records ADC conversion result for current sense 
 *             of CH2 (Two LSBs) */

#define TPS274C65_ADC_RESULT_CH2_I_LSB_REG 0x0E

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Least Significant Bits for ADC result from conversion of the current in 
        * CH2 */
        unsigned ADC_ISNS_CH2_LSB : 2;
        /* Reserved */
        unsigned RESERVED_22 : 6;
    } bits;
} TPS274C65_ADC_RESULT_CH2_I_LSB;

#define TPS274C65_ADC_RESULT_CH2_I_LSB_ADC_ISNS_CH2_LSB_MASK 0x03
#define TPS274C65_ADC_RESULT_CH2_I_LSB_RESERVED_22_MASK 0xFC

/* --------- TPS274C65_ADC_RESULT_CH3_I (0x0F) ----------*/
/* DESCRIPTION: The register records ADC conversion result for current sense 
 *             of CH3 */

#define TPS274C65_ADC_RESULT_CH3_I_REG 0x0F

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the current in CH3 */
        unsigned ADC_ISNS_CH3 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH3_I;

#define TPS274C65_ADC_RESULT_CH3_I_ADC_ISNS_CH3_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH3_I_LSB (0x10) ----------*/
/* DESCRIPTION: The register records ADC conversion result for current sense 
 *             of CH3 (Two LSBs) */

#define TPS274C65_ADC_RESULT_CH3_I_LSB_REG 0x10

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Least Significant Bits for ADC result from conversion of the current in 
        * CH3 */
        unsigned ADC_ISNS_CH3_LSB : 2;
        /* Reserved */
        unsigned RESERVED_24 : 6;
    } bits;
} TPS274C65_ADC_RESULT_CH3_I_LSB;

#define TPS274C65_ADC_RESULT_CH3_I_LSB_ADC_ISNS_CH3_LSB_MASK 0x03
#define TPS274C65_ADC_RESULT_CH3_I_LSB_RESERVED_24_MASK 0xFC

/* --------- TPS274C65_ADC_RESULT_CH4_I (0x11) ----------*/
/* DESCRIPTION: The register records ADC conversion result for current sense 
 *             of CH4 */

#define TPS274C65_ADC_RESULT_CH4_I_REG 0x11

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the current in CH4 */
        unsigned ADC_ISNS_CH4 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH4_I;

#define TPS274C65_ADC_RESULT_CH4_I_ADC_ISNS_CH4_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH4_I_LSB (0x12) ----------*/
/* DESCRIPTION: The register records ADC conversion result for current sense 
 *             of CH4 (Two LSBs) */

#define TPS274C65_ADC_RESULT_CH4_I_LSB_REG 0x12

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Least Significant Bits for ADC result from conversion of the current in 
        * CH4 */
        unsigned ADC_ISNS_CH4_LSB : 2;
        /* Reserved */
        unsigned RESERVED_26 : 6;
    } bits;
} TPS274C65_ADC_RESULT_CH4_I_LSB;

#define TPS274C65_ADC_RESULT_CH4_I_LSB_ADC_ISNS_CH4_LSB_MASK 0x03
#define TPS274C65_ADC_RESULT_CH4_I_LSB_RESERVED_26_MASK 0xFC

/* --------- TPS274C65_ADC_RESULT_CH1_T (0x13) ----------*/
/* DESCRIPTION: The register records ADC conversion result for temperature 
 *             sense of CH1 */

#define TPS274C65_ADC_RESULT_CH1_T_REG 0x13

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the temperature in CH1 */
        unsigned ADC_TSNS_CH1 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH1_T;

#define TPS274C65_ADC_RESULT_CH1_T_ADC_TSNS_CH1_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH2_T (0x14) ----------*/
/* DESCRIPTION: The register records ADC conversion result for temperature 
 *             sense of CH2 */

#define TPS274C65_ADC_RESULT_CH2_T_REG 0x14

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the temperature in CH2 */
        unsigned ADC_TSNS_CH2 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH2_T;

#define TPS274C65_ADC_RESULT_CH2_T_ADC_TSNS_CH2_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH3_T (0x15) ----------*/
/* DESCRIPTION: The register records ADC conversion result for temperature 
 *             sense of CH3 */

#define TPS274C65_ADC_RESULT_CH3_T_REG 0x15

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the temperature in CH3 */
        unsigned ADC_TSNS_CH3 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH3_T;

#define TPS274C65_ADC_RESULT_CH3_T_ADC_TSNS_CH3_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH4_T (0x16) ----------*/
/* DESCRIPTION: The register records ADC conversion result for temperature 
 *             sense of CH4 */

#define TPS274C65_ADC_RESULT_CH4_T_REG 0x16

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the temperature in CH4 */
        unsigned ADC_TSNS_CH4 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH4_T;

#define TPS274C65_ADC_RESULT_CH4_T_ADC_TSNS_CH4_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH1_V (0x17) ----------*/
/* DESCRIPTION: The register records ADC conversion result for voltage sense 
 *             of CH1 */

#define TPS274C65_ADC_RESULT_CH1_V_REG 0x17

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the voltage in CH1 */
        unsigned ADC_VSNS_CH1 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH1_V;

#define TPS274C65_ADC_RESULT_CH1_V_ADC_VSNS_CH1_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH2_V (0x18) ----------*/
/* DESCRIPTION: The register records ADC conversion result for voltage sense 
 *             of CH2 */

#define TPS274C65_ADC_RESULT_CH2_V_REG 0x18

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the voltage in CH2 */
        unsigned ADC_VSNS_CH2 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH2_V;

#define TPS274C65_ADC_RESULT_CH2_V_ADC_VSNS_CH2_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH3_V (0x19) ----------*/
/* DESCRIPTION: The register records ADC conversion result for voltage sense 
 *             of CH3 */

#define TPS274C65_ADC_RESULT_CH3_V_REG 0x19

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the voltage in CH3 */
        unsigned ADC_VSNS_CH3 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH3_V;

#define TPS274C65_ADC_RESULT_CH3_V_ADC_VSNS_CH3_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_CH4_V (0x1A) ----------*/
/* DESCRIPTION: The register records ADC conversion result for voltage sense 
 *             of CH4 */

#define TPS274C65_ADC_RESULT_CH4_V_REG 0x1A

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the voltage in CH4 */
        unsigned ADC_VSNS_CH4 : 8;
    } bits;
} TPS274C65_ADC_RESULT_CH4_V;

#define TPS274C65_ADC_RESULT_CH4_V_ADC_VSNS_CH4_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_VS (0x1B) ----------*/
/* DESCRIPTION: The register records ADC conversion result for supply voltage 
 *             sense */

#define TPS274C65_ADC_RESULT_VS_REG 0x1B

typedef union 
{
    uint8_t byte;
    struct
    {
        /* ADC result (8-bits) from the conversion of the supply voltage input (VS 
        * pin) */
        unsigned ADC_VS_SNS : 8;
    } bits;
} TPS274C65_ADC_RESULT_VS;

#define TPS274C65_ADC_RESULT_VS_ADC_VS_SNS_MASK 0xFF

/* --------- TPS274C65_ADC_RESULT_VS_LSB (0x1C) ----------*/
/* DESCRIPTION: The register records ADC conversion result for supply voltage 
 *             sense (Two LSBs) */

#define TPS274C65_ADC_RESULT_VS_LSB_REG 0x1C

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Least Significant Bits for ADC result from conversion of the supply voltage 
        * input (VS pin) */
        unsigned ADC_VS_SNS_CH4_LSB : 2;
        /* Reserved */
        unsigned RESERVED_28 : 6;
    } bits;
} TPS274C65_ADC_RESULT_VS_LSB;

#define TPS274C65_ADC_RESULT_VS_LSB_ADC_VS_SNS_CH4_LSB_MASK 0x03
#define TPS274C65_ADC_RESULT_VS_LSB_RESERVED_28_MASK 0xFC

/* --------- TPS274C65_SW_STATE (0x1D) ----------*/
/* DESCRIPTION: The register sets the switch state (ON/OFF) of each output 
 *             channel. The switch state bits in the SPI frame are ignored when a write 
 *             to this register is performed (only the contents of the DATA_IN field 
 *             of the SPI frame are used to update the switch state) */

#define TPS274C65_SW_STATE_REG 0x1D

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to turn on the FET and CH1 output ON */
        unsigned CH1_ON : 1;
        /* Set this bit to 1 to turn on the FET and CH2 output ON */
        unsigned CH2_ON : 1;
        /* Set this bit to 1 to turn on the FET and CH3 output ON */
        unsigned CH3_ON : 1;
        /* Set this bit to 1 to turn on the FET and CH4 output ON */
        unsigned CH4_ON : 1;
        /* Reserved */
        unsigned RESERVED_30 : 4;
    } bits;
} TPS274C65_SW_STATE;

#define TPS274C65_SW_STATE_CH1_ON_MASK 0x01

typedef enum {
    ch1_on_en_1_0x0 = 0x0,
    ch1_on_en_2_0x1 = 0x1,
} ch1_on_t;

#define TPS274C65_SW_STATE_CH2_ON_MASK 0x02

typedef enum {
    ch2_on_en_1_0x0 = 0x0,
    ch2_on_en_2_0x1 = 0x2,
} ch2_on_t;

#define TPS274C65_SW_STATE_CH3_ON_MASK 0x04

typedef enum {
    ch3_on_en_1_0x0 = 0x0,
    ch3_on_en_2_0x1 = 0x4,
} ch3_on_t;

#define TPS274C65_SW_STATE_CH4_ON_MASK 0x08

typedef enum {
    ch4_on_en_1_0x0 = 0x0,
    ch4_on_en_2_0x1 = 0x8,
} ch4_on_t;

#define TPS274C65_SW_STATE_RESERVED_30_MASK 0xF0

/* --------- TPS274C65_LED1_4_CTL (0x1E) ----------*/
/* DESCRIPTION: The register sets the LEDs ON or OFF */

#define TPS274C65_LED1_4_CTL_REG 0x1E

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to turn on the LED1 Output Status indicator */
        unsigned LED1_CTL : 1;
        /* Set this bit to 1 to turn on the LED2 Output Status indicator */
        unsigned LED2_CTL : 1;
        /* Set this bit to 1 to turn on the LED3 Output Status indicator */
        unsigned LED3_CTL : 1;
        /* Set this bit to 1 to turn on the LED4 Output Status indicator */
        unsigned LED4_CTL : 1;
        /* Reserved */
        unsigned RESERVED_32 : 4;
    } bits;
} TPS274C65_LED1_4_CTL;

#define TPS274C65_LED1_4_CTL_LED1_CTL_MASK 0x01

typedef enum {
    led1_ctl_en_1_0x0 = 0x0,
    led1_ctl_en_2_0x1 = 0x1,
} led1_ctl_t;

#define TPS274C65_LED1_4_CTL_LED2_CTL_MASK 0x02

typedef enum {
    led2_ctl_en_1_0x0 = 0x0,
    led2_ctl_en_2_0x1 = 0x2,
} led2_ctl_t;

#define TPS274C65_LED1_4_CTL_LED3_CTL_MASK 0x04

typedef enum {
    led3_ctl_en_1_0x0 = 0x0,
    led3_ctl_en_2_0x1 = 0x4,
} led3_ctl_t;

#define TPS274C65_LED1_4_CTL_LED4_CTL_MASK 0x08

typedef enum {
    led4_ctl_en_1_0x0 = 0x0,
    led4_ctl_en_2_0x1 = 0x8,
} led4_ctl_t;

#define TPS274C65_LED1_4_CTL_RESERVED_32_MASK 0xF0

/* --------- TPS274C65_LED_5_8_CTL (0x1F) ----------*/
/* DESCRIPTION: The register sets the LEDs ON or OFF */

#define TPS274C65_LED_5_8_CTL_REG 0x1F

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to turn on the LED5 Output Status indicator */
        unsigned LED5_CTL : 1;
        /* Set this bit to 1 to turn on the LED6 Output Status indicator */
        unsigned LED6_CTL : 1;
        /* Set this bit to 1 to turn on the LED7 Output Status indicator */
        unsigned LED7_CTL : 1;
        /* Set this bit to 1 to turn on the LED8 Output Status indicator */
        unsigned LED8_CTL : 1;
        /* Reserved */
        unsigned RESERVED_34 : 4;
    } bits;
} TPS274C65_LED_5_8_CTL;

#define TPS274C65_LED_5_8_CTL_LED5_CTL_MASK 0x01

typedef enum {
    led5_ctl_en_1_0x0 = 0x0,
    led5_ctl_en_2_0x1 = 0x1,
} led5_ctl_t;

#define TPS274C65_LED_5_8_CTL_LED6_CTL_MASK 0x02

typedef enum {
    led6_ctl_en_1_0x0 = 0x0,
    led6_ctl_en_2_0x1 = 0x2,
} led6_ctl_t;

#define TPS274C65_LED_5_8_CTL_LED7_CTL_MASK 0x04

typedef enum {
    led7_ctl_en_1_0x0 = 0x0,
    led7_ctl_en_2_0x1 = 0x4,
} led7_ctl_t;

#define TPS274C65_LED_5_8_CTL_LED8_CTL_MASK 0x08

typedef enum {
    led8_ctl_en_1_0x0 = 0x0,
    led8_ctl_en_2_0x1 = 0x8,
} led8_ctl_t;

#define TPS274C65_LED_5_8_CTL_RESERVED_34_MASK 0xF0

/* --------- TPS274C65_FS_SW_STATE (0x20) ----------*/
/* DESCRIPTION: The register sets the switch state (ON/OFF) of each output 
 *             channel in case of SPI_ERR or WD_ERR */

#define TPS274C65_FS_SW_STATE_REG 0x20

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to turn on the CH1 FET and CH4 Output ON when WD_ERR 
        * fault has occurred */
        unsigned CH1_FS_ON : 1;
        /* Set this bit to 1 to turn on the CH2 FET and CH4 Output ON when WD_ERR 
        * fault has occurred */
        unsigned CH2_FS_ON : 1;
        /* Set this bit to 1 to turn on the CH3 FET and CH4 Output ON when WD_ERR 
        * fault has occurred */
        unsigned CH3_FS_ON : 1;
        /* Set this bit to 1 to turn on the CH4 FET and CH4 Output ON when WD_ERR 
        * fault has occurred */
        unsigned CH4_FS_ON : 1;
        /* Reserved */
        unsigned RESERVED_36 : 4;
    } bits;
} TPS274C65_FS_SW_STATE;

#define TPS274C65_FS_SW_STATE_CH1_FS_ON_MASK 0x01

typedef enum {
    ch1_fs_on_en_1_0x0 = 0x0,
    ch1_fs_on_en_2_0x1 = 0x1,
} ch1_fs_on_t;

#define TPS274C65_FS_SW_STATE_CH2_FS_ON_MASK 0x02

typedef enum {
    ch2_fs_on_en_1_0x0 = 0x0,
    ch2_fs_on_en_2_0x1 = 0x2,
} ch2_fs_on_t;

#define TPS274C65_FS_SW_STATE_CH3_FS_ON_MASK 0x04

typedef enum {
    ch3_fs_on_en_1_0x0 = 0x0,
    ch3_fs_on_en_2_0x1 = 0x4,
} ch3_fs_on_t;

#define TPS274C65_FS_SW_STATE_CH4_FS_ON_MASK 0x08

typedef enum {
    ch4_fs_on_en_1_0x0 = 0x0,
    ch4_fs_on_en_2_0x1 = 0x8,
} ch4_fs_on_t;

#define TPS274C65_FS_SW_STATE_RESERVED_36_MASK 0xF0

/* --------- TPS274C65_DEV_CONFIG1 (0x21) ----------*/
/* DESCRIPTION: Current limit setting and duration of initial inrush level 
 *             and time channel 1/2 */

#define TPS274C65_DEV_CONFIG1_REG 0x21

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Sets the current limit regulation value during overcurrent or shirt circuit 
        * events (Ch1 and Ch2). See table of current limit settings in the datasheet. 
        * */
        unsigned ILIM_REG_12 : 4;
        /* Sets the delay period during with inrush current limit level applies (Ch1 
        * and Ch2). See table of delay settings in the datasheet */
        unsigned ILIM_DURATION_12 : 4;
    } bits;
} TPS274C65_DEV_CONFIG1;

#define TPS274C65_DEV_CONFIG1_ILIM_REG_12_MASK 0x0F
#define TPS274C65_DEV_CONFIG1_ILIM_DURATION_12_MASK 0xF0

/* --------- TPS274C65_DEV_CONFIG2 (0x22) ----------*/
/* DESCRIPTION: Current limit setting and duration of initial inrush level 
 *             and time channel 3/4 */

#define TPS274C65_DEV_CONFIG2_REG 0x22

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Sets the current limit regulation value during overcurrent or shirt circuit 
        * events(Ch3 and Ch4). See table of current limit settings in the datasheet. 
        * */
        unsigned ILIM_REG_34 : 4;
        /* Sets the delay period during with inrush current limit level applies (Ch3 
        * and Ch4). See table of delay settings in the datasheet */
        unsigned ILIM_DURATION_34 : 4;
    } bits;
} TPS274C65_DEV_CONFIG2;

#define TPS274C65_DEV_CONFIG2_ILIM_REG_34_MASK 0x0F
#define TPS274C65_DEV_CONFIG2_ILIM_DURATION_34_MASK 0xF0

/* --------- TPS274C65_DEV_CONFIG3 (0x23) ----------*/
/* DESCRIPTION: Device Configuration register - RCB function disable in all 
 *             channels,Sense current range Inrush current Limit level config, Parallel 
 *             chanel config Inrush current Limit level config, ILIM type config inrush 
 *             or current limit duration */

#define TPS274C65_DEV_CONFIG3_REG 0x23

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Sets the inrush current limit level that applies during the duration of 
        * ILIM inrush duration. See table of inrush current limit level settings 
        * in the datasheet */
        unsigned INRUSH_LIMIT : 2;
        /* Set this bit to 1 to have the ILIM duration applied as the period of inrush 
        * current limit or to set as the duration of current limiting before switching 
        * off the FET. */
        unsigned ILIM_CONFIG : 1;
        /* Set this bit to 1 to signal that channels 1 and 2(CH1 and CH2) are paralleled. 
        * Write to this bit is valid only when all four SW_STATE bits are 0 and not 
        * rewritten to 1 in the same frame. */
        unsigned PARALLEL_12 : 1;
        /* Set this bit to 1 to signal that channels 3 and 4 (CH3 and CH4) are paralleled. 
        * Write to this bit is valid only when all four SW_STATE bits are 0 and not 
        * rewritten to 1 in the same frame. */
        unsigned PARALLEL_34 : 1;
        /* Sets the load current sense range - optimizing the current sense output 
        * */
        unsigned ISNS_RANGE : 1;
        /* Set this bit to allow CH1/CH2 to have different current limit setting 
        * than CH3/CH4 */
        unsigned ILIM_SET : 1;
        /* Setting this bit to 1, disable RCB function in all channels */
        unsigned RCB_DIS : 1;
    } bits;
} TPS274C65_DEV_CONFIG3;

#define TPS274C65_DEV_CONFIG3_INRUSH_LIMIT_MASK 0x03
#define TPS274C65_DEV_CONFIG3_ILIM_CONFIG_MASK 0x04

typedef enum {
    ilim_config_en_1_0x0 = 0x0,
    ilim_config_en_2_0x1 = 0x4,
} ilim_config_t;

#define TPS274C65_DEV_CONFIG3_PARALLEL_12_MASK 0x08

typedef enum {
    parallel_12_en_1_0x0 = 0x0,
    parallel_12_en_2_0x1 = 0x8,
} parallel_12_t;

#define TPS274C65_DEV_CONFIG3_PARALLEL_34_MASK 0x10

typedef enum {
    parallel_34_en_1_0x0 = 0x0,
    parallel_34_en_2_0x1 = 0x10,
} parallel_34_t;

#define TPS274C65_DEV_CONFIG3_ISNS_RANGE_MASK 0x20

typedef enum {
    isns_range_en_1_0x0 = 0x0,
    isns_range_en_2_0x1 = 0x20,
} isns_range_t;

#define TPS274C65_DEV_CONFIG3_ILIM_SET_MASK 0x40

typedef enum {
    ilim_set_en_1_0x0 = 0x0,
    ilim_set_en_2_0x1 = 0x40,
} ilim_set_t;

#define TPS274C65_DEV_CONFIG3_RCB_DIS_MASK 0x80

typedef enum {
    rcb_dis_en_1_0x0 = 0x0,
    rcb_dis_en_2_0x1 = 0x80,
} rcb_dis_t;


/* --------- TPS274C65_DEV_CONFIG4 (0x24) ----------*/
/* DESCRIPTION: Device Configuration register - Configuring WB_on_threshold 
 *             current. WB_off PU current, Watchdog enable and timer duration */

#define TPS274C65_DEV_CONFIG4_REG 0x24

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Sets the current threshold for on-state wire-break (open load) detection. 
        * See table of settings in the datasheet */
        unsigned WB_ON_THD : 3;
        /* Sets the pullup current value (at the OUTx pins) by the off-state wire-break 
        * (open load) detection circuit. */
        unsigned WB_OFF_PU : 2;
        /* Sets the timeout period for the SPI watchdog monitor */
        unsigned WD_TO : 2;
        /* The bit is set to enable the watchdog function */
        unsigned WD_EN : 1;
    } bits;
} TPS274C65_DEV_CONFIG4;

#define TPS274C65_DEV_CONFIG4_WB_ON_THD_MASK 0x07
#define TPS274C65_DEV_CONFIG4_WB_OFF_PU_MASK 0x18

typedef enum {
    wb_off_pu_en_1_0x0 = 0x0,
    wb_off_pu_en_2_0x1 = 0x8,
    wb_off_pu_en_3_0x2 = 0x10,
    wb_off_pu_en_4_0x3 = 0x18,
} wb_off_pu_t;

#define TPS274C65_DEV_CONFIG4_WD_TO_MASK 0x60

typedef enum {
    wd_to_en_1_0x0 = 0x0,
    wd_to_en_2_0x1 = 0x20,
    wd_to_en_3_0x2 = 0x40,
    wd_to_en_4_0x3 = 0x60,
} wd_to_t;

#define TPS274C65_DEV_CONFIG4_WD_EN_MASK 0x80

typedef enum {
    wd_en_en_1_0x0 = 0x0,
    wd_en_en_2_0x1 = 0x80,
} wd_en_t;


/* --------- TPS274C65_DEV_CONFIG5 (0x25) ----------*/
/* DESCRIPTION: Device Configuration register - Device Configuration register 
 *             - Fault bit LATCH_mode enable, ,Wire break or short to VS blanking time 
 *             in off-state,Sw_STATE config, fault latch with retry only on enable toggle. 
 *             */

#define TPS274C65_DEV_CONFIG5_REG 0x25

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to not latch the fault bits in the register and cleared 
        * on read. */
        unsigned FLT_LTCH_DIS : 1;
        /* Set this bit to 1 to have the outputs hold state when WD_ERR faults have 
        * occurred. Otherwise the device uses the FS_SW_STATE register bits. */
        unsigned SW_FS_CFG : 1;
        /* Sets the blanking time for wire-break (ON-state  and OFF-state) and the 
        * short_to_VS faults before the fault is registered. */
        unsigned WB_SVS_BLANK : 2;
        /* Setting this bit to 1, disables the auto-retry and latches the channel 
        * Output OFF on thermal shutdown of the channel occurs. Retry can be attempted 
        * by toggling enable. */
        unsigned AUTO_RETRY_DIS : 1;
        /* Setting this bit to 1, enables the ADC function */
        unsigned ADC_EN : 1;
        /* Reserved */
        unsigned RESERVED_38 : 2;
    } bits;
} TPS274C65_DEV_CONFIG5;

#define TPS274C65_DEV_CONFIG5_FLT_LTCH_DIS_MASK 0x01

typedef enum {
    flt_ltch_dis_en_1_0x0 = 0x0,
    flt_ltch_dis_en_2_0x1 = 0x1,
} flt_ltch_dis_t;

#define TPS274C65_DEV_CONFIG5_SW_FS_CFG_MASK 0x02

typedef enum {
    sw_fs_cfg_en_1_0x0 = 0x0,
    sw_fs_cfg_en_2_0x1 = 0x2,
} sw_fs_cfg_t;

#define TPS274C65_DEV_CONFIG5_WB_SVS_BLANK_MASK 0x0C

typedef enum {
    wb_svs_blank_en_1_0x0 = 0x0,
    wb_svs_blank_en_2_0x1 = 0x4,
    wb_svs_blank_en_3_0x2 = 0x8,
    wb_svs_blank_en_4_0x3 = 0xc,
} wb_svs_blank_t;

#define TPS274C65_DEV_CONFIG5_AUTO_RETRY_DIS_MASK 0x10

typedef enum {
    auto_retry_dis_en_1_0x0 = 0x0,
    auto_retry_dis_en_2_0x1 = 0x10,
} auto_retry_dis_t;

#define TPS274C65_DEV_CONFIG5_ADC_EN_MASK 0x20

typedef enum {
    adc_en_en_1_0x0 = 0x0,
    adc_en_en_2_0x1 = 0x20,
} adc_en_t;

#define TPS274C65_DEV_CONFIG5_RESERVED_38_MASK 0xC0

/* --------- TPS274C65_DEV_CONFIG6 (0x26) ----------*/
/* DESCRIPTION: Device Configuration register - Per Channel RCB FET gate 
 *             off configuration */

#define TPS274C65_DEV_CONFIG6_REG 0x26

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Bit determines the reverse current blocking FET gate control in CH1 */
        unsigned RCB_CH1 : 1;
        /* Bit determines the reverse current blocking FET gate control in CH2 */
        unsigned RCB_CH2 : 1;
        /* Bit determines the reverse current blocking FET gate control in CH3 */
        unsigned RCB_CH3 : 1;
        /* Bit determines the reverse current blocking FET gate control in CH4 */
        unsigned RCB_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_40 : 4;
    } bits;
} TPS274C65_DEV_CONFIG6;

#define TPS274C65_DEV_CONFIG6_RCB_CH1_MASK 0x01

typedef enum {
    rcb_ch1_en_1_0x0 = 0x0,
    rcb_ch1_en_2_0x1 = 0x1,
} rcb_ch1_t;

#define TPS274C65_DEV_CONFIG6_RCB_CH2_MASK 0x02

typedef enum {
    rcb_ch2_en_1_0x0 = 0x0,
    rcb_ch2_en_2_0x1 = 0x2,
} rcb_ch2_t;

#define TPS274C65_DEV_CONFIG6_RCB_CH3_MASK 0x04

typedef enum {
    rcb_ch3_en_1_0x0 = 0x0,
    rcb_ch3_en_2_0x1 = 0x4,
} rcb_ch3_t;

#define TPS274C65_DEV_CONFIG6_RCB_CH4_MASK 0x08

typedef enum {
    rcb_ch4_en_1_0x0 = 0x0,
    rcb_ch4_en_2_0x1 = 0x8,
} rcb_ch4_t;

#define TPS274C65_DEV_CONFIG6_RESERVED_40_MASK 0xF0

/* --------- TPS274C65_FAULT_MASK (0x27) ----------*/
/* DESCRIPTION: The register allows masking of certain types of faults. */

#define TPS274C65_FAULT_MASK_REG 0x27

typedef union 
{
    uint8_t byte;
    struct
    {
        /* The bit is set to mask the supply voltage VS UV fault signaling on the 
        * FLT pin output. */
        unsigned MASK_VS_UV : 1;
        /* The bit is set to mask the signaling on-state wire-break fault on the 
        * FLT pin */
        unsigned MASK_WB_ON : 1;
        /* The bit is set to mask the signaling off-state wire-break fault on the 
        * FLT pin */
        unsigned MASK_WB_OFF : 1;
        /* The bit is set to mask the signaling off-state Short to VS fault on the 
        * FLT pin */
        unsigned MASK_SHRT_VS : 1;
        /* The bit is set to mask the signaling reverse current fault on the FLT 
        * pin */
        unsigned MASK_RVRS_BLK : 1;
        /* The bit is set to mask the signaling ILIMIT fault on the FLT pin */
        unsigned MASK_ILIMIT : 1;
        /* The bit is set to mask the SPI watchdog error (WD_ERR)  signaling in the 
        *  FLT pin output and FAULT_TYPE_STAT register */
        unsigned MASK_WD_ERR : 1;
        /* The bit is set to mask the SPI error (SPI_ERR)  signaling in the  FLT 
        * pin output and FAULT_TYPE_STAT register */
        unsigned MASK_SPI_ERR : 1;
    } bits;
} TPS274C65_FAULT_MASK;

#define TPS274C65_FAULT_MASK_MASK_VS_UV_MASK 0x01

typedef enum {
    mask_vs_uv_en_1_0x0 = 0x0,
    mask_vs_uv_en_2_0x1 = 0x1,
} mask_vs_uv_t;

#define TPS274C65_FAULT_MASK_MASK_WB_ON_MASK 0x02

typedef enum {
    mask_wb_on_en_1_0x0 = 0x0,
    mask_wb_on_en_2_0x1 = 0x2,
} mask_wb_on_t;

#define TPS274C65_FAULT_MASK_MASK_WB_OFF_MASK 0x04

typedef enum {
    mask_wb_off_en_1_0x0 = 0x0,
    mask_wb_off_en_2_0x1 = 0x4,
} mask_wb_off_t;

#define TPS274C65_FAULT_MASK_MASK_SHRT_VS_MASK 0x08

typedef enum {
    mask_shrt_vs_en_1_0x0 = 0x0,
    mask_shrt_vs_en_2_0x1 = 0x8,
} mask_shrt_vs_t;

#define TPS274C65_FAULT_MASK_MASK_RVRS_BLK_MASK 0x10

typedef enum {
    mask_rvrs_blk_en_1_0x0 = 0x0,
    mask_rvrs_blk_en_2_0x1 = 0x10,
} mask_rvrs_blk_t;

#define TPS274C65_FAULT_MASK_MASK_ILIMIT_MASK 0x20

typedef enum {
    mask_ilimit_en_1_0x0 = 0x0,
    mask_ilimit_en_2_0x1 = 0x20,
} mask_ilimit_t;

#define TPS274C65_FAULT_MASK_MASK_WD_ERR_MASK 0x40

typedef enum {
    mask_wd_err_en_1_0x0 = 0x0,
    mask_wd_err_en_2_0x1 = 0x40,
} mask_wd_err_t;

#define TPS274C65_FAULT_MASK_MASK_SPI_ERR_MASK 0x80

typedef enum {
    mask_spi_err_en_1_0x0 = 0x0,
    mask_spi_err_en_2_0x1 = 0x80,
} mask_spi_err_t;


/* --------- TPS274C65_EN_WB_OFF (0x28) ----------*/
/* DESCRIPTION: Enables diagnostic of the wire-break (off-state) faults in 
 *             the fault registers */

#define TPS274C65_EN_WB_OFF_REG 0x28

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to enable the wire-break (off-state) fault in CH1 */
        unsigned WB_OFF_CH1_EN : 1;
        /* Set this bit to 1 to enable the wire-break (off-state) fault in CH2 */
        unsigned WB_OFF_CH2_EN : 1;
        /* Set this bit to 1 to enable the wire-break (off-state) fault in CH3 */
        unsigned WB_OFF_CH3_EN : 1;
        /* Set this bit to 1 to enable the wire-break (off-state) fault in CH4 */
        unsigned WB_OFF_CH4_EN : 1;
        /* Reserved */
        unsigned RESERVED_42 : 4;
    } bits;
} TPS274C65_EN_WB_OFF;

#define TPS274C65_EN_WB_OFF_WB_OFF_CH1_EN_MASK 0x01

typedef enum {
    wb_off_ch1_en_en_1_0x0 = 0x0,
    wb_off_ch1_en_en_2_0x1 = 0x1,
} wb_off_ch1_en_t;

#define TPS274C65_EN_WB_OFF_WB_OFF_CH2_EN_MASK 0x02

typedef enum {
    wb_off_ch2_en_en_1_0x0 = 0x0,
    wb_off_ch2_en_en_2_0x1 = 0x2,
} wb_off_ch2_en_t;

#define TPS274C65_EN_WB_OFF_WB_OFF_CH3_EN_MASK 0x04

typedef enum {
    wb_off_ch3_en_en_1_0x0 = 0x0,
    wb_off_ch3_en_en_2_0x1 = 0x4,
} wb_off_ch3_en_t;

#define TPS274C65_EN_WB_OFF_WB_OFF_CH4_EN_MASK 0x08

typedef enum {
    wb_off_ch4_en_en_1_0x0 = 0x0,
    wb_off_ch4_en_en_2_0x1 = 0x8,
} wb_off_ch4_en_t;

#define TPS274C65_EN_WB_OFF_RESERVED_42_MASK 0xF0

/* --------- TPS274C65_EN_WB_ON (0x29) ----------*/
/* DESCRIPTION: The register allows masking of On-state Wire-break fault 
 *             per channel */

#define TPS274C65_EN_WB_ON_REG 0x29

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to enable the wire-break (off-state) fault diagnostic 
        * in CH1 */
        unsigned WB_ON_CH1_EN : 1;
        /* Set this bit to 1 to enable the wire-break (off-state) fault diagnostic 
        * in CH2 */
        unsigned WB_ON_CH2_EN : 1;
        /* Set this bit to 1 to enable the wire-break (off-state) fault diagnostic 
        * in CH3 */
        unsigned WB_ON_CH3_EN : 1;
        /* Set this bit to 1 to enable the wire-break (off-state) fault diagnostic 
        * in CH4 */
        unsigned WB_ON_CH4_EN : 1;
        /* Reserved */
        unsigned RESERVED_44 : 4;
    } bits;
} TPS274C65_EN_WB_ON;

#define TPS274C65_EN_WB_ON_WB_ON_CH1_EN_MASK 0x01

typedef enum {
    wb_on_ch1_en_en_1_0x0 = 0x0,
    wb_on_ch1_en_en_2_0x1 = 0x1,
} wb_on_ch1_en_t;

#define TPS274C65_EN_WB_ON_WB_ON_CH2_EN_MASK 0x02

typedef enum {
    wb_on_ch2_en_en_1_0x0 = 0x0,
    wb_on_ch2_en_en_2_0x1 = 0x2,
} wb_on_ch2_en_t;

#define TPS274C65_EN_WB_ON_WB_ON_CH3_EN_MASK 0x04

typedef enum {
    wb_on_ch3_en_en_1_0x0 = 0x0,
    wb_on_ch3_en_en_2_0x1 = 0x4,
} wb_on_ch3_en_t;

#define TPS274C65_EN_WB_ON_WB_ON_CH4_EN_MASK 0x08

typedef enum {
    wb_on_ch4_en_en_1_0x0 = 0x0,
    wb_on_ch4_en_en_2_0x1 = 0x8,
} wb_on_ch4_en_t;

#define TPS274C65_EN_WB_ON_RESERVED_44_MASK 0xF0

/* --------- TPS274C65_EN_SHRT_VS (0x2A) ----------*/
/* DESCRIPTION: The register allows masking of output short to supply (VS) 
 *             fault per channel */

#define TPS274C65_EN_SHRT_VS_REG 0x2A

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to enable the short_to_VS (off-state) fault diagnostic 
        * in CH1 */
        unsigned SHRT_VS_CH1_EN : 1;
        /* Set this bit to 1 to enable the short_to_VS (off-state) fault diagnostic 
        * in CH2 */
        unsigned SHRT_VS_CH2_EN : 1;
        /* Set this bit to 1 to enable the short_to_VS (off-state) fault diagnostic 
        * in CH3 */
        unsigned SHRT_VS_CH3_EN : 1;
        /* Set this bit to 1 to enable the short_to_VS (off-state) fault diagnostic 
        * in CH4 */
        unsigned SHRT_VS_CH4_EN : 1;
        /* Reserved */
        unsigned RESERVED_46 : 4;
    } bits;
} TPS274C65_EN_SHRT_VS;

#define TPS274C65_EN_SHRT_VS_SHRT_VS_CH1_EN_MASK 0x01

typedef enum {
    shrt_vs_ch1_en_en_1_0x0 = 0x0,
    shrt_vs_ch1_en_en_2_0x1 = 0x1,
} shrt_vs_ch1_en_t;

#define TPS274C65_EN_SHRT_VS_SHRT_VS_CH2_EN_MASK 0x02

typedef enum {
    shrt_vs_ch2_en_en_1_0x0 = 0x0,
    shrt_vs_ch2_en_en_2_0x1 = 0x2,
} shrt_vs_ch2_en_t;

#define TPS274C65_EN_SHRT_VS_SHRT_VS_CH3_EN_MASK 0x04

typedef enum {
    shrt_vs_ch3_en_en_1_0x0 = 0x0,
    shrt_vs_ch3_en_en_2_0x1 = 0x4,
} shrt_vs_ch3_en_t;

#define TPS274C65_EN_SHRT_VS_SHRT_VS_CH4_EN_MASK 0x08

typedef enum {
    shrt_vs_ch4_en_en_1_0x0 = 0x0,
    shrt_vs_ch4_en_en_2_0x1 = 0x8,
} shrt_vs_ch4_en_t;

#define TPS274C65_EN_SHRT_VS_RESERVED_46_MASK 0xF0

/* --------- TPS274C65_ADC_ISNS_DIS (0x2B) ----------*/
/* DESCRIPTION: Allows disabling the ADC conversion of ISNS on a per channel 
 *             basis */

#define TPS274C65_ADC_ISNS_DIS_REG 0x2B

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 disable ISNS_CH1 conversion */
        unsigned ISNS_DIS_CH1 : 1;
        /* Set this bit to 1 disable ISNS_CH2 conversion */
        unsigned ISNS_DIS_CH2 : 1;
        /* Set this bit to 1 disable ISNS_CH3 conversion */
        unsigned ISNS_DIS_CH3 : 1;
        /* Set this bit to 1 disable ISNS_CH4 conversion */
        unsigned ISNS_DIS_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_48 : 4;
    } bits;
} TPS274C65_ADC_ISNS_DIS;

#define TPS274C65_ADC_ISNS_DIS_ISNS_DIS_CH1_MASK 0x01

typedef enum {
    isns_dis_ch1_en_1_0x0 = 0x0,
    isns_dis_ch1_en_2_0x1 = 0x1,
} isns_dis_ch1_t;

#define TPS274C65_ADC_ISNS_DIS_ISNS_DIS_CH2_MASK 0x02

typedef enum {
    isns_dis_ch2_en_1_0x0 = 0x0,
    isns_dis_ch2_en_2_0x1 = 0x2,
} isns_dis_ch2_t;

#define TPS274C65_ADC_ISNS_DIS_ISNS_DIS_CH3_MASK 0x04

typedef enum {
    isns_dis_ch3_en_1_0x0 = 0x0,
    isns_dis_ch3_en_2_0x1 = 0x4,
} isns_dis_ch3_t;

#define TPS274C65_ADC_ISNS_DIS_ISNS_DIS_CH4_MASK 0x08

typedef enum {
    isns_dis_ch4_en_1_0x0 = 0x0,
    isns_dis_ch4_en_2_0x1 = 0x8,
} isns_dis_ch4_t;

#define TPS274C65_ADC_ISNS_DIS_RESERVED_48_MASK 0xF0

/* --------- TPS274C65_ADC_TSNS_DIS (0x2C) ----------*/
/* DESCRIPTION: Allows disabling the ADC conversion of TSNS on a per channel 
 *             basis */

#define TPS274C65_ADC_TSNS_DIS_REG 0x2C

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 disable TSNS_CH1 conversion */
        unsigned TSNS_DIS_CH1 : 1;
        /* Set this bit to 1 disable TSNS_CH2 conversion */
        unsigned TSNS_DIS_CH2 : 1;
        /* Set this bit to 1 disable TSNS_CH3 conversion */
        unsigned TSNS_DIS_CH3 : 1;
        /* Set this bit to 1 disable TSNS_CH4 conversion */
        unsigned TSNS_DIS_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_50 : 4;
    } bits;
} TPS274C65_ADC_TSNS_DIS;

#define TPS274C65_ADC_TSNS_DIS_TSNS_DIS_CH1_MASK 0x01

typedef enum {
    tsns_dis_ch1_en_1_0x0 = 0x0,
    tsns_dis_ch1_en_2_0x1 = 0x1,
} tsns_dis_ch1_t;

#define TPS274C65_ADC_TSNS_DIS_TSNS_DIS_CH2_MASK 0x02

typedef enum {
    tsns_dis_ch2_en_1_0x0 = 0x0,
    tsns_dis_ch2_en_2_0x1 = 0x2,
} tsns_dis_ch2_t;

#define TPS274C65_ADC_TSNS_DIS_TSNS_DIS_CH3_MASK 0x04

typedef enum {
    tsns_dis_ch3_en_1_0x0 = 0x0,
    tsns_dis_ch3_en_2_0x1 = 0x4,
} tsns_dis_ch3_t;

#define TPS274C65_ADC_TSNS_DIS_TSNS_DIS_CH4_MASK 0x08

typedef enum {
    tsns_dis_ch4_en_1_0x0 = 0x0,
    tsns_dis_ch4_en_2_0x1 = 0x8,
} tsns_dis_ch4_t;

#define TPS274C65_ADC_TSNS_DIS_RESERVED_50_MASK 0xF0

/* --------- TPS274C65_ADC_VSNS_DIS (0x2D) ----------*/
/* DESCRIPTION: Allows disabling the ADC conversion of VSNS on a per channel 
 *             basis */

#define TPS274C65_ADC_VSNS_DIS_REG 0x2D

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 disable VSNS_CH1 conversion */
        unsigned VSNS_DIS_CH1 : 1;
        /* Set this bit to 1 disable VSNS_CH2 conversion */
        unsigned VSNS_DIS_CH2 : 1;
        /* Set this bit to 1 disable VSNS_CH3 conversion */
        unsigned VSNS_DIS_CH3 : 1;
        /* Set this bit to 1 disable VSNS_CH4 conversion */
        unsigned VSNS_DIS_CH4 : 1;
        /* Reserved */
        unsigned RESERVED_52 : 4;
    } bits;
} TPS274C65_ADC_VSNS_DIS;

#define TPS274C65_ADC_VSNS_DIS_VSNS_DIS_CH1_MASK 0x01

typedef enum {
    vsns_dis_ch1_en_1_0x0 = 0x0,
    vsns_dis_ch1_en_2_0x1 = 0x1,
} vsns_dis_ch1_t;

#define TPS274C65_ADC_VSNS_DIS_VSNS_DIS_CH2_MASK 0x02

typedef enum {
    vsns_dis_ch2_en_1_0x0 = 0x0,
    vsns_dis_ch2_en_2_0x1 = 0x2,
} vsns_dis_ch2_t;

#define TPS274C65_ADC_VSNS_DIS_VSNS_DIS_CH3_MASK 0x04

typedef enum {
    vsns_dis_ch3_en_1_0x0 = 0x0,
    vsns_dis_ch3_en_2_0x1 = 0x4,
} vsns_dis_ch3_t;

#define TPS274C65_ADC_VSNS_DIS_VSNS_DIS_CH4_MASK 0x08

typedef enum {
    vsns_dis_ch4_en_1_0x0 = 0x0,
    vsns_dis_ch4_en_2_0x1 = 0x8,
} vsns_dis_ch4_t;

#define TPS274C65_ADC_VSNS_DIS_RESERVED_52_MASK 0xF0

/* --------- TPS274C65_ADC_CONFIG1 (0x2E) ----------*/
/* DESCRIPTION: ADC configuration - disable conversion of measurements not 
 *             needed. */

#define TPS274C65_ADC_CONFIG1_REG 0x2E

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to disable supply voltage V_VS conversion in the ADC 
        * conversion sequence. */
        unsigned ADC_VS_DIS : 1;
        /* Set this bit to 1 to disable ISNS ADC functionality */
        unsigned ADC_ISNS_DIS : 1;
        /* Set this bit to 1 to disable the VSNS ADC functionality */
        unsigned ADC_VSNS_DIS : 1;
        /* Set this bit to 1 to disable the ADC TSNS functionality */
        unsigned ADC_TSNS_DIS : 1;
        /* Reserved */
        unsigned RESERVED_54 : 4;
    } bits;
} TPS274C65_ADC_CONFIG1;

#define TPS274C65_ADC_CONFIG1_ADC_VS_DIS_MASK 0x01

typedef enum {
    adc_vs_dis_en_1_0x0 = 0x0,
    adc_vs_dis_en_2_0x1 = 0x1,
} adc_vs_dis_t;

#define TPS274C65_ADC_CONFIG1_ADC_ISNS_DIS_MASK 0x02

typedef enum {
    adc_isns_dis_en_1_0x0 = 0x0,
    adc_isns_dis_en_2_0x1 = 0x2,
} adc_isns_dis_t;

#define TPS274C65_ADC_CONFIG1_ADC_VSNS_DIS_MASK 0x04

typedef enum {
    adc_vsns_dis_en_1_0x0 = 0x0,
    adc_vsns_dis_en_2_0x1 = 0x4,
} adc_vsns_dis_t;

#define TPS274C65_ADC_CONFIG1_ADC_TSNS_DIS_MASK 0x08

typedef enum {
    adc_tsns_dis_en_1_0x0 = 0x0,
    adc_tsns_dis_en_2_0x1 = 0x8,
} adc_tsns_dis_t;

#define TPS274C65_ADC_CONFIG1_RESERVED_54_MASK 0xF0

/* --------- TPS274C65_CRC_CONFIG (0x2F) ----------*/
/* DESCRIPTION: Configure CRC */

#define TPS274C65_CRC_CONFIG_REG 0x2F

typedef union 
{
    uint8_t byte;
    struct
    {
        /* Set this bit to 1 to enable CRC check of SPI command frame. */
        unsigned CRC_EN : 1;
        /* Set this bit to 1 to use 24-bit SPI command frame in daisy chain mode 
        * */
        unsigned D24BIT : 1;
        /* Reserved */
        unsigned RESERVED_56 : 6;
    } bits;
} TPS274C65_CRC_CONFIG;

#define TPS274C65_CRC_CONFIG_CRC_EN_MASK 0x01

typedef enum {
    crc_en_en_1_0x0 = 0x0,
    crc_en_en_2_0x1 = 0x1,
} crc_en_t;

#define TPS274C65_CRC_CONFIG_D24BIT_MASK 0x02

typedef enum {
    d24bit_en_1_0x0 = 0x0,
    d24bit_en_2_0x1 = 0x2,
} d24bit_t;

#define TPS274C65_CRC_CONFIG_RESERVED_56_MASK 0xFC

